# 🚀 **girokmoji** Release Changelog v0.5.3


_"Change is always thrilling!"_  
_(And sometimes a little confusing.)_
    

**Release Date:** 2025-02-10


---


## Feature and Functional Changes

**New features that make you go "Wow!"**

- **🔖 Release / Version tags.**: [*release 0.5.3 with beta and lower version python support*](../../commit/97b4bd68171424785ea232a5146af7ed2e9482e0)
- **🔖 Release / Version tags.**: [*v0.5.2*](../../commit/72156cdcc8242f072a53d95e114602c1ab2d939c)
- **✨ Introduce new features.**: [*Clickable commit*](../../commit/bc5102d35f3eadb2ab3c378add7057b79f15bc00)
- **🎉 Begin a project.**: [*initial pypi version*](../../commit/85695e985ae99057cc7f1ff165aaac72eab1a8a8)
- **🚀 Deploy stuff.**: [*release initial version*](../../commit/f9d672c6077744ffd25b1961b94484348ee1f2a1)
- **✨ Introduce new features.**: [*main CLI function*](../../commit/da822cbfb9ed6b2ecec7e02cb958952669c1bea9)
- **✨ Introduce new features.**: [*template generation*](../../commit/4a018ccbfee1f0ed0a7c2d04cf64a6438ad4c800)
- **✨ Introduce new features.**: [*git-related features using minimal deps*](../../commit/d11642c8e45a73f3cebba5a03e3dc33f296a3392)
- **✨ Introduce new features.**: [*category-based gitmoji*](../../commit/4a7c2598784c3cab66ce51b91cb91fcfb9caa1b9)

---


## Bug Fixes

**Stubborn bugs have been squashed!**

- **🐛 Fix a bug.**: [*fix bug by swapping str var*](../../commit/19cee80aeaab29d4c53d78c9389af44e4012a84b)

---


## Lint

**Polishing code style and eliminating lint warnings!**

- **🚨 Fix compiler / linter warnings.**: [*minor linting*](../../commit/ef097c431ff3675957e0ee771b5fb445e15164f2)

---


## Documentation and Comment

**Documentation and comments are the developer’s conscience.**

- **📝 Add or update documentation.**: [*add example*](../../commit/a12f22f6103f04f1a08efb98e9fa48bbcbad5482)
- **📝 Add or update documentation.**: [*add initial README.md*](../../commit/b478e14c6f0c99f40b6d4f600fd4bc89dabdc926)

---


## Dependency, Build, and Configuration

**From dependency management to build scripts, everything has been updated!**

- **📌 Pin dependencies to specific versions.**: [*pin python runtime version to min supported version*](../../commit/42074bbac700e75f2b8dc7aee69140b026703e91)

---


## File and Project Management

**Managing file moves, removals, and project documentation.**

- **🙈 Add or update a .gitignore file.**: [*add common python gitignore*](../../commit/f68505cac76efc899392817b41f354b581c02996)
- **📄 Add or update license.**: [*add license*](../../commit/783fb9e492dae44e061a05d95e75d0a2de912791)

---


## Internalization, Accessibility, and UI/UX

**Making the project accessible and appealing to everyone worldwide!**

- **🚸 Improve user experience / usability.**: [*touches on markdown generation*](../../commit/895076de2fab197032e3f115852e374d87af0bc9)

---
